@@ -18,15 +18,26 @@ from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
-from .paginator import GetAppMonitorDataPaginator, ListAppMonitorsPaginator
+from .literals import MetricDestinationType
+from .paginator import (
+    BatchGetRumMetricDefinitionsPaginator,
+    GetAppMonitorDataPaginator,
+    ListAppMonitorsPaginator,
+    ListRumMetricsDestinationsPaginator,
+)
 from .type_defs import (
     AppMonitorConfigurationTypeDef,
     AppMonitorDetailsTypeDef,
+    BatchCreateRumMetricDefinitionsResponseTypeDef,
+    BatchDeleteRumMetricDefinitionsResponseTypeDef,
+    BatchGetRumMetricDefinitionsResponseTypeDef,
     CreateAppMonitorResponseTypeDef,
     GetAppMonitorDataResponseTypeDef,
     GetAppMonitorResponseTypeDef,
     ListAppMonitorsResponseTypeDef,
+    ListRumMetricsDestinationsResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
+    MetricDefinitionRequestTypeDef,
     QueryFilterTypeDef,
     RumEventTypeDef,
     TimeRangeTypeDef,
@@ -78,6 +89,55 @@ class CloudWatchRUMClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#exceptions)
         """
 
+    def batch_create_rum_metric_definitions(
+        self,
+        *,
+        AppMonitorName: str,
+        Destination: MetricDestinationType,
+        MetricDefinitions: Sequence[MetricDefinitionRequestTypeDef],
+        DestinationArn: str = ...
+    ) -> BatchCreateRumMetricDefinitionsResponseTypeDef:
+        """
+        Specifies the extended metrics that you want a CloudWatch RUM app monitor to
+        send to a destination.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Client.batch_create_rum_metric_definitions)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#batch_create_rum_metric_definitions)
+        """
+
+    def batch_delete_rum_metric_definitions(
+        self,
+        *,
+        AppMonitorName: str,
+        Destination: MetricDestinationType,
+        MetricDefinitionIds: Sequence[str],
+        DestinationArn: str = ...
+    ) -> BatchDeleteRumMetricDefinitionsResponseTypeDef:
+        """
+        Removes the specified metrics from being sent to an extended metrics
+        destination.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Client.batch_delete_rum_metric_definitions)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#batch_delete_rum_metric_definitions)
+        """
+
+    def batch_get_rum_metric_definitions(
+        self,
+        *,
+        AppMonitorName: str,
+        Destination: MetricDestinationType,
+        DestinationArn: str = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
+    ) -> BatchGetRumMetricDefinitionsResponseTypeDef:
+        """
+        Retrieves the list of metrics and dimensions that a RUM app monitor is sending
+        to a single destination.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Client.batch_get_rum_metric_definitions)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#batch_get_rum_metric_definitions)
+        """
+
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
@@ -119,6 +179,17 @@ class CloudWatchRUMClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#delete_app_monitor)
         """
 
+    def delete_rum_metrics_destination(
+        self, *, AppMonitorName: str, Destination: MetricDestinationType, DestinationArn: str = ...
+    ) -> Dict[str, Any]:
+        """
+        Deletes a destination for CloudWatch RUM extended metrics, so that the specified
+        app monitor stops sending extended metrics to that destination.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Client.delete_rum_metrics_destination)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#delete_rum_metrics_destination)
+        """
+
     def generate_presigned_url(
         self,
         ClientMethod: str,
@@ -168,6 +239,17 @@ class CloudWatchRUMClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#list_app_monitors)
         """
 
+    def list_rum_metrics_destinations(
+        self, *, AppMonitorName: str, MaxResults: int = ..., NextToken: str = ...
+    ) -> ListRumMetricsDestinationsResponseTypeDef:
+        """
+        Returns a list of destinations that you have created to receive RUM extended
+        metrics, for the specified app monitor.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Client.list_rum_metrics_destinations)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#list_rum_metrics_destinations)
+        """
+
     def list_tags_for_resource(self, *, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
         Displays the tags associated with a CloudWatch RUM resource.
@@ -193,6 +275,22 @@ class CloudWatchRUMClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#put_rum_events)
         """
 
+    def put_rum_metrics_destination(
+        self,
+        *,
+        AppMonitorName: str,
+        Destination: MetricDestinationType,
+        DestinationArn: str = ...,
+        IamRoleArn: str = ...
+    ) -> Dict[str, Any]:
+        """
+        Creates or updates a destination to receive extended metrics from CloudWatch
+        RUM.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Client.put_rum_metrics_destination)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#put_rum_metrics_destination)
+        """
+
     def tag_resource(self, *, ResourceArn: str, Tags: Mapping[str, str]) -> Dict[str, Any]:
         """
         Assigns one or more tags (key-value pairs) to the specified CloudWatch RUM
@@ -225,6 +323,31 @@ class CloudWatchRUMClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#update_app_monitor)
         """
 
+    def update_rum_metric_definition(
+        self,
+        *,
+        AppMonitorName: str,
+        Destination: MetricDestinationType,
+        MetricDefinition: MetricDefinitionRequestTypeDef,
+        MetricDefinitionId: str,
+        DestinationArn: str = ...
+    ) -> Dict[str, Any]:
+        """
+        Modifies one existing metric definition for CloudWatch RUM extended metrics.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Client.update_rum_metric_definition)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#update_rum_metric_definition)
+        """
+
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["batch_get_rum_metric_definitions"]
+    ) -> BatchGetRumMetricDefinitionsPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#get_paginator)
+        """
+
     @overload
     def get_paginator(
         self, operation_name: Literal["get_app_monitor_data"]
@@ -242,3 +365,12 @@ class CloudWatchRUMClient(BaseClient):
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Client.get_paginator)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#get_paginator)
         """
+
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["list_rum_metrics_destinations"]
+    ) -> ListRumMetricsDestinationsPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rum/client/#get_paginator)
+        """
