@@ -6,9 +6,9 @@ Type annotations for rum service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_rum.literals import GetAppMonitorDataPaginatorName
+    from mypy_boto3_rum.literals import BatchGetRumMetricDefinitionsPaginatorName
 
-    data: GetAppMonitorDataPaginatorName = "get_app_monitor_data"
+    data: BatchGetRumMetricDefinitionsPaginatorName = "batch_get_rum_metric_definitions"
     ```
 """
 import sys
@@ -20,8 +20,11 @@ else:
 
 
 __all__ = (
+    "BatchGetRumMetricDefinitionsPaginatorName",
     "GetAppMonitorDataPaginatorName",
     "ListAppMonitorsPaginatorName",
+    "ListRumMetricsDestinationsPaginatorName",
+    "MetricDestinationType",
     "StateEnumType",
     "TelemetryType",
     "CloudWatchRUMServiceName",
@@ -32,8 +35,11 @@ __all__ = (
 )
 
 
+BatchGetRumMetricDefinitionsPaginatorName = Literal["batch_get_rum_metric_definitions"]
 GetAppMonitorDataPaginatorName = Literal["get_app_monitor_data"]
 ListAppMonitorsPaginatorName = Literal["list_app_monitors"]
+ListRumMetricsDestinationsPaginatorName = Literal["list_rum_metrics_destinations"]
+MetricDestinationType = Literal["CloudWatch", "Evidently"]
 StateEnumType = Literal["ACTIVE", "CREATED", "DELETING"]
 TelemetryType = Literal["errors", "http", "performance"]
 CloudWatchRUMServiceName = Literal["rum"]
@@ -67,6 +73,7 @@ ServiceName = Literal[
     "autoscaling-plans",
     "backup",
     "backup-gateway",
+    "backupstorage",
     "batch",
     "billingconductor",
     "braket",
@@ -108,7 +115,9 @@ ServiceName = Literal[
     "connect",
     "connect-contact-lens",
     "connectcampaigns",
+    "connectcases",
     "connectparticipant",
+    "controltower",
     "cur",
     "customer-profiles",
     "databrew",
@@ -186,6 +195,7 @@ ServiceName = Literal[
     "iotevents",
     "iotevents-data",
     "iotfleethub",
+    "iotfleetwise",
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
@@ -212,6 +222,7 @@ ServiceName = Literal[
     "lexv2-models",
     "lexv2-runtime",
     "license-manager",
+    "license-manager-user-subscriptions",
     "lightsail",
     "location",
     "logs",
@@ -240,6 +251,7 @@ ServiceName = Literal[
     "mgn",
     "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhuborchestrator",
     "migrationhubstrategy",
     "mobile",
     "mq",
@@ -265,6 +277,7 @@ ServiceName = Literal[
     "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
+    "privatenetworks",
     "proton",
     "qldb",
     "qldb-session",
@@ -327,6 +340,7 @@ ServiceName = Literal[
     "storagegateway",
     "sts",
     "support",
+    "support-app",
     "swf",
     "synthetics",
     "textract",
@@ -361,7 +375,12 @@ ResourceServiceName = Literal[
     "sns",
     "sqs",
 ]
-PaginatorName = Literal["get_app_monitor_data", "list_app_monitors"]
+PaginatorName = Literal[
+    "batch_get_rum_metric_definitions",
+    "get_app_monitor_data",
+    "list_app_monitors",
+    "list_rum_metrics_destinations",
+]
 RegionName = Literal[
     "ap-northeast-1",
     "ap-southeast-1",
